@@ -26,7 +26,7 @@
 #include "kurl.h"
 
 class CheckoutInfo_impl: public CheckoutInfo {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     CheckoutInfo_impl(TQWidget *parent = 0, const char *name = 0);
