@@ -33,7 +33,7 @@ CheckModifiedThread::CheckModifiedThread(TQObject*_parent,const TQString&what,bo
     m_Parent = _parent;
     m_CurrentContext = new svn::Context();
     m_ContextListener = new ThreadContextListener(m_Parent);
-    TQObject::connect(m_ContextListener,TQT_SIGNAL(sendNotify(const TQString&)),m_Parent,TQT_SLOT(slotNotifyMessage(const TQString&)));
+    TQObject::connect(m_ContextListener,TQ_SIGNAL(sendNotify(const TQString&)),m_Parent,TQ_SLOT(slotNotifyMessage(const TQString&)));
 
     m_CurrentContext->setListener(m_ContextListener);
     m_what = what;
