@@ -46,7 +46,7 @@ namespace svn {
 
 class PropertiesDlg : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
