@@ -34,7 +34,7 @@ class SvnActions;
 
 class SvnLogDlgImp: public SvnLogDialogData,public SimpleLogCb
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     SvnLogDlgImp(SvnActions*,TQWidget *parent = 0, const char *name = 0,bool modal=true);
