@@ -52,7 +52,7 @@ namespace svn {
 */
 class tdesvnfilelist : public TDEListView,public ItemDisplay
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     friend class FileListViewItem;
 public:
