@@ -7,19 +7,12 @@
 
 #include "svnqt/client.h"
 #include "svnqt/svnqttypes.h"
-#include "svnqt/log_entry.h"
 
 #include "svnqt/cache/LogCache.h"
 #include "svnqt/cache/ReposLog.h"
 #include "svnqt/cache/test/testconfig.h"
 #include "svnqt/cache/DatabaseException.h"
 
-#if [[[TQT_VERSION IS DEPRECATED]]] < 0x040000
-#else
-#include <TQSqlQuery>
-#include <TQSqlError>
-#endif
-
 int main(int argc,char**argv)
 {
     TQApplication app(argc,argv);
@@ -43,19 +36,11 @@ int main(int argc,char**argv)
     }
     svn::cache::ReposLog rl(m_Svnclient,"http://www.alwins-world.de/repos/tdesvn");
     TQDataBase db = rl.Database();
-#if [[[TQT_VERSION IS DEPRECATED]]] < 0x040000
     if (!db) {
-#else
-    if (!db.isValid()) {
-#endif
         std::cerr << "No database object."<<std::endl;
         exit(-1);
     }
-#if [[[TQT_VERSION IS DEPRECATED]]] < 0x040000
     list = db->tables();
-#else
-    list = db.tables();
-#endif
     it = list.begin();
     while( it != list.end() ) {
         std::cout << ( *it ).TOUTF8().data() << std::endl;
@@ -91,10 +76,6 @@ int main(int argc,char**argv)
     q.exec();
     std::cerr << "\n" << q.lastError().text().TOUTF8().data()<<std::endl;
 
-#if [[[TQT_VERSION IS DEPRECATED]]] < 0x040000
-#else
-    db=TQSqlDatabase();
-#endif
     try {
         rl.log("/trunk/src/svnqt",1,1000,svn::Revision::UNDEFINED,lm,false,-1);
     }
