@@ -52,7 +52,7 @@ apr_array_header_t* svn_sort__hash(apr_hash_t *ht,
   ary = apr_array_make(pool, apr_hash_count(ht), sizeof(svn_sort_item_type));
 
   /* loop over hash table and push all keys into the array */
-  sorted = TRUE;
+  sorted = true;
   prev_item = NULL;
   for (hi = apr_hash_first(pool, ht); hi; hi = apr_hash_next(hi))
 	{
