@@ -34,7 +34,7 @@ namespace svn
   void
   Client_impl::lock (const Targets & targets,
     const TQString& message,
-    bool steal_lock)  throw (ClientException)
+    bool steal_lock)
   {
     Pool pool;
     svn_error_t * error =
@@ -49,7 +49,7 @@ namespace svn
 
   void
   Client_impl::unlock (const Targets&targets,
-            bool break_lock)  throw (ClientException)
+            bool break_lock)
   {
     Pool pool;
     svn_error_t * error =
