@@ -207,7 +207,7 @@ SvnByteStream::SvnByteStream(svn_client_ctx_t * ctx)
 {
     m_ByteData = new SvnByteStream_private;
     if (!m_ByteData->mBuf.isOpen()) {
-        setError(TQT_TQIODEVICE_OBJECT(m_ByteData->mBuf).status());
+        setError(m_ByteData->mBuf.status());
     }
 }
 
@@ -220,7 +220,7 @@ long SvnByteStream::write(const char*aData,const unsigned long max)
 {
     long i = m_ByteData->mBuf.writeBlock(aData,max);
     if (i<0) {
-        setError(TQT_TQIODEVICE_OBJECT(m_ByteData->mBuf).status());
+        setError(m_ByteData->mBuf.status());
     }
     return i;
 }
