@@ -42,7 +42,7 @@
 #include <kdebug.h>
 #include <tdemacros.h>
 #include <tdemessagebox.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeglobal.h>
 #include <kstandarddirs.h>
 #include <tdelocale.h>
