@@ -33,7 +33,7 @@
 #include "helpers/ktranslateurl.h"
 #include "helpers/sshagent.h"
 
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeaction.h>
 #include <kstdaction.h>
 #include <tdefiledialog.h>
