@@ -69,31 +69,31 @@ tdesvnView::tdesvnView(TDEActionCollection*aCollection,TQWidget *parent,const ch
     m_topLayout = new TQVBoxLayout(this);
 
     m_Splitter = new TQSplitter( this, "m_Splitter" );
-    m_Splitter->setOrientation( Qt::Vertical );
+    m_Splitter->setOrientation( TQt::Vertical );
 
     m_flist=new tdesvnfilelist(m_Collection,m_Splitter);
 
     m_infoSplitter = new TQSplitter(m_Splitter);
-    m_infoSplitter->setOrientation( Qt::Horizontal );
+    m_infoSplitter->setOrientation( TQt::Horizontal );
     m_infoSplitter->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 1, m_infoSplitter->sizePolicy().hasHeightForWidth() ) );
     m_LogWindow=new KTextBrowser(m_infoSplitter);
     Propertylist*pl = new Propertylist(m_infoSplitter);
     pl->setCommitchanges(true);
-    pl->addCallback(TQT_TQOBJECT(m_flist));
-    connect(m_flist,TQT_SIGNAL(sigProplist(const svn::PathPropertiesMapListPtr&,bool,const TQString&)),
-            pl,TQT_SLOT(displayList(const svn::PathPropertiesMapListPtr&,bool,const TQString&)));
+    pl->addCallback(m_flist);
+    connect(m_flist,TQ_SIGNAL(sigProplist(const svn::PathPropertiesMapListPtr&,bool,const TQString&)),
+            pl,TQ_SLOT(displayList(const svn::PathPropertiesMapListPtr&,bool,const TQString&)));
 
     m_flist->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)7, (TQSizePolicy::SizeType)7, 0, 1, m_flist->sizePolicy().hasHeightForWidth() ) );
 
     m_topLayout->addWidget(m_Splitter);
-    connect(m_flist,TQT_SIGNAL(sigLogMessage(const TQString&)),this,TQT_SLOT(slotAppendLog(const TQString&)));
-    connect(m_flist,TQT_SIGNAL(changeCaption(const TQString&)),this,TQT_SLOT(slotSetTitle(const TQString&)));
-    connect(m_flist,TQT_SIGNAL(sigShowPopup(const TQString&,TQWidget**)),this,TQT_SLOT(slotDispPopup(const TQString&,TQWidget**)));
-    connect(m_flist,TQT_SIGNAL(sigUrlOpend(bool)),parent,TQT_SLOT(slotUrlOpened(bool)));
-    connect(m_flist,TQT_SIGNAL(sigSwitchUrl(const KURL&)),this,TQT_SIGNAL(sigSwitchUrl(const KURL&)));
-    connect(m_flist,TQT_SIGNAL(sigUrlChanged( const TQString& )),this,TQT_SLOT(slotUrlChanged(const TQString&)));
-    connect(m_flist,TQT_SIGNAL(sigCacheStatus(TQ_LONG,TQ_LONG)),this,TQT_SLOT(fillCacheStatus(TQ_LONG,TQ_LONG)));
-    connect(this,TQT_SIGNAL(sigMakeBaseDirs()),m_flist,TQT_SLOT(slotMkBaseDirs()));
+    connect(m_flist,TQ_SIGNAL(sigLogMessage(const TQString&)),this,TQ_SLOT(slotAppendLog(const TQString&)));
+    connect(m_flist,TQ_SIGNAL(changeCaption(const TQString&)),this,TQ_SLOT(slotSetTitle(const TQString&)));
+    connect(m_flist,TQ_SIGNAL(sigShowPopup(const TQString&,TQWidget**)),this,TQ_SLOT(slotDispPopup(const TQString&,TQWidget**)));
+    connect(m_flist,TQ_SIGNAL(sigUrlOpend(bool)),parent,TQ_SLOT(slotUrlOpened(bool)));
+    connect(m_flist,TQ_SIGNAL(sigSwitchUrl(const KURL&)),this,TQ_SIGNAL(sigSwitchUrl(const KURL&)));
+    connect(m_flist,TQ_SIGNAL(sigUrlChanged( const TQString& )),this,TQ_SLOT(slotUrlChanged(const TQString&)));
+    connect(m_flist,TQ_SIGNAL(sigCacheStatus(TQ_LONG,TQ_LONG)),this,TQ_SLOT(fillCacheStatus(TQ_LONG,TQ_LONG)));
+    connect(this,TQ_SIGNAL(sigMakeBaseDirs()),m_flist,TQ_SLOT(slotMkBaseDirs()));
     TDEConfigGroup cs(Kdesvnsettings::self()->config(),"tdesvn-mainlayout");
     TQString t1 = cs.readEntry("split1",TQString());
     if (!t1.isEmpty()) {
@@ -239,7 +239,7 @@ void tdesvnView::slotSettingsChanged()
 void tdesvnView::slotCreateRepo()
 {
     KDialogBase * dlg = new KDialogBase(
-        TQT_TQWIDGET(TDEApplication::activeModalWidget()),
+        TDEApplication::activeModalWidget(),
         "create_repository",
         true,
         i18n("Create new repository"),
@@ -287,7 +287,7 @@ void tdesvnView::slotCreateRepo()
 void tdesvnView::slotHotcopy()
 {
     KDialogBase * dlg = new KDialogBase(
-        TQT_TQWIDGET(TDEApplication::activeModalWidget()),
+        TDEApplication::activeModalWidget(),
         "hotcopy_repository",
         true,
         i18n("Hotcopy a repository"),
@@ -322,7 +322,7 @@ void tdesvnView::slotHotcopy()
 void tdesvnView::slotLoaddump()
 {
     KDialogBase dlg(
-        TQT_TQWIDGET(TDEApplication::activeModalWidget()),
+        TDEApplication::activeModalWidget(),
         "hotcopy_repository",
         true,
         i18n("Hotcopy a repository"),
@@ -360,7 +360,7 @@ void tdesvnView::slotLoaddump()
         break;
     }
     try {
-        StopDlg sdlg(TQT_TQOBJECT(this),this,0,"Load Dump",i18n("Loading a dump into a repository."));
+        StopDlg sdlg(this,this,0,"Load Dump",i18n("Loading a dump into a repository."));
         _rep.loaddump(ptr->dumpFile(),_act,ptr->parentPath(),ptr->usePre(),ptr->usePost());
         slotAppendLog(i18n("Loading dump finished."));
     }catch (const svn::ClientException&e) {
@@ -372,7 +372,7 @@ void tdesvnView::slotLoaddump()
 void tdesvnView::slotDumpRepo()
 {
     KDialogBase * dlg = new KDialogBase(
-        TQT_TQWIDGET(TDEApplication::activeModalWidget()),
+        TDEApplication::activeModalWidget(),
         "dump_repository",
         true,
         i18n("Dump a repository"),
@@ -421,7 +421,7 @@ void tdesvnView::slotDumpRepo()
     }
 
     try {
-        StopDlg sdlg(TQT_TQOBJECT(this),this,0,"Dump",i18n("Dumping a repository"));
+        StopDlg sdlg(this,this,0,"Dump",i18n("Dumping a repository"));
         _rep->dump(out,st,en,incr,diffs);
         slotAppendLog(i18n("Dump finished."));
     }catch (const svn::ClientException&e) {
